@@ -10,17 +10,22 @@ use List::Util qw/reduce/;
 use List::MoreUtils qw/natatime/;
 use Exporter 5.57 qw/import/;
 
-our @EXPORT_OK = qw/query_handle/;
+our @EXPORT_OK = qw/query_handle get_layers/;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 
 XSLoader::load(__PACKAGE__, $VERSION);
 
+our %FLAG_FOR;
 sub _names_to_flags {
-	our %FLAG_FOR;
 	return reduce { $a | $b } map { $FLAG_FOR{$_} } @_;
 }
 
+sub _flag_names {
+	my $flagbits = shift;
+	return grep { $FLAG_FOR{$_} & $flagbits } keys %FLAG_FOR;
+}
+
 sub _has_flags {
 	my $check_flag = _names_to_flags(@_);
 	return sub {
@@ -64,12 +69,21 @@ my %query_for = (
 
 sub query_handle {
 	my ($fh, $query_name, @args) = @_;
-	my @results;
 	my $query = $query_for{$query_name} or croak "Query $query_name isn't defined";
 	my $iterator = natatime(3, PerlIO::get_layers($fh, details => 1));
 	return $query->($iterator, @args);
 }
 
+sub get_layers {
+	my $fh = shift;
+	my @results;
+	my $iterator = natatime(3, PerlIO::get_layers($fh, details => 1));
+	while (my ($name, $arguments, $flags) = $iterator->()) {
+		push @results, [ $name, $arguments, [ _flag_names($flags) ] ];
+	}
+	return @results;
+}
+
 1;    # End of PerlIO::Layers
 
 __END__
@@ -80,7 +94,7 @@ PerlIO::Layers - Querying your filehandle's capabilities
 
 =head1 VERSION
 
-Version 0.003
+Version 0.004
 
 =head1 SYNOPSIS
 
@@ -136,6 +150,76 @@ Check whether the filehandle refers to a temporary file.
 
 =back
 
+=head2 get_layers($fh)
+
+Gets information on the layers of a filehandle. It's a list with whose entries have 3 elements: the name of the layer, the arguments of the layer (may be undef) and an arrayref with the flags of the layer as strings. The flags array can contain any of these values.
+
+=over 4
+
+=item * EOF
+
+End of file has been reached.
+
+=item * CANWRITE
+
+Writes are permitted, i.e. opened as ">" or "+<" or ">>", etc.
+
+=item * CANREAD
+
+Reads are permitted i.e. opened "<" or "+>".
+
+=item * ERROR
+
+An error has occurred.
+
+=item * TRUNCATE
+
+Truncate file suggested by open mode.
+
+=item * APPEND
+
+All writes should be appends.
+
+=item * CRLF
+
+Layer is performing Win32-like "\n" mapped to CR,LF for output and CR,LF mapped to "\n" for input. Normally the provided "crlf" layer is the only layer that need bother about this. C<binmode> will mess with this flag rather than add/remove layers if the PERLIO_K_CANCRLF bit is set for the layers class.
+
+=item * UTF8
+
+Data written to this layer should be UTF-8 encoded; data provided by this layer should be considered UTF-8 encoded. Can be set on any layer by ":utf8" dummy layer. Also set on ":encoding" layer.
+
+=item * UNBUF
+
+Layer is unbuffered - i.e. write to next layer down should occur for each write to this layer.
+
+=item * WRBUF
+
+The buffer for this layer currently holds data written to it but not sent to next layer.
+
+=item * RDBUF
+
+The buffer for this layer currently holds unconsumed data read from layer below.
+
+=item * LINEBUF
+
+Layer is line buffered. Write data should be passed to next layer down whenever a "\n" is seen. Any data beyond the "\n" should then be processed.
+
+=item * TEMP
+
+File has been unlink()ed, or should be deleted on close().
+
+=item * OPEN
+
+Handle is open.
+
+=item * FASTGETS
+
+This instance of this layer supports the "fast gets " interface. Normally set based on PERLIO_K_FASTGETS for the class and by the existence of the function(s) in the table. However a class that normally provides that interface may need to avoid it on a particular instance. The "pending" layer needs to do this when it is pushed above a layer which does not support the interface.
+
+=back
+
+query_handle provides a more high level interface to this, you should probably use that when you can.
+
 =head1 AUTHOR
 
 Leon Timmermans, C<< <leont at cpan.org> >>
